@@ -1,11 +1,13 @@
 package Data::Collector::Info::ExternalIP;
 
+use Carp;
 use Moose;
 use LWP::UserAgent;
 use MooseX::StrictConstructor;
 use namespace::autoclean;
 
 extends 'Data::Collector::Info';
+with    'Data::Collector::Commands';
 
 has 'url' => (
     is      => 'ro',
@@ -18,7 +20,14 @@ sub load { Data::Collector::Info->register_keys('external_ip') }
 sub _build_raw_data {
     my $self = shift;
     my $url  = $self->url;
-    $self->engine->run("curl $url 2>/dev/null");
+    my $curl = $self->get_command('curl');
+    my $data = $self->engine->run("$curl $url 2>/dev/null");
+
+    if ( $data =~ /(\d+\.\d+\.\d+\.\d+)/ ) {
+        return $1;
+    }
+
+    croak q{Coulnd't find IP in output};
 }
 
 sub all {
